@@ -128,8 +128,8 @@ def create_new_data_set(request):
     if request.app is not None:
         data_set = request.app.create_new_data_set_for_user(
             authenticated_userid(request),
-            request.matchdict['data_set_template'],
-            request.matchdict['data_set_name']
+            request.POST['data_set_template'],
+            request.POST['data_set_name']
         )
         return {
             'success': True,
